@@ -48,7 +48,7 @@ from netbox_storage.views.logical_volume import LogicalVolumeDeleteView, Logical
 from netbox_storage.views.physical_volume import PhysicalVolumeDeleteView, PhysicalVolumeEditView, PhysicalVolumeView, \
     PhysicalVolumeListView, PhysicalVolumeBulkImportView, PhysicalVolumeBulkEditView, PhysicalVolumeBulkDeleteView
 from netbox_storage.views.template import LVMAddTemplateView, AddTemplateDriveView, \
-    AddTemplatePartitionView
+    AddTemplatePartitionView, SyncTemplateToVMView
 from netbox_storage.views.volume_group import VolumeGroupDeleteView, VolumeGroupEditView, VolumeGroupView, \
     VolumeGroupListView, VolumeGroupBulkImportView, VolumeGroupBulkEditView, VolumeGroupBulkDeleteView
 
@@ -202,5 +202,6 @@ urlpatterns = [
     #
     path('template-lvm-add/', LVMAddTemplateView.as_view(), name='template_lvm_add'),
     path('template-drive-add/', AddTemplateDriveView.as_view(), name='template_drive_add'),
-    path('template-partition-add', AddTemplatePartitionView.as_view(), name='template_partition_add')
+    path('template-partition-add', AddTemplatePartitionView.as_view(), name='template_partition_add'),
+    path('sync-template-to-vm/', SyncTemplateToVMView.as_view(), name='sync-template-to-vm')
 ]
